dictloader – BRDR - Aligning borders

# DictLoader

    loader.DictLoader(
        data_dict,
        data_dict_properties={},
        data_dict_source={'source_url': None},
        is_reference=False,
    )

Loader that accepts data directly from Python dictionaries.

Useful for integrating with existing in-memory data structures.

## Methods

Name | Description
--- | ---
load_data | Executes the standard loading process.

### load_data

    loader.DictLoader.load_data()

Executes the standard loading process.